aboutsummaryrefslogtreecommitdiffstats
path: root/src/exiv2wrapper.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/exiv2wrapper.hpp')
-rw-r--r--src/exiv2wrapper.hpp19
1 files changed, 13 insertions, 6 deletions
diff --git a/src/exiv2wrapper.hpp b/src/exiv2wrapper.hpp
index 763a398..371cfe3 100644
--- a/src/exiv2wrapper.hpp
+++ b/src/exiv2wrapper.hpp
@@ -30,7 +30,7 @@
#include <string>
#include "exiv2/image.hpp"
-#include "exiv2/exif.hpp"
+//#include "exiv2/exif.hpp"
//#include "exiv2/iptc.hpp"
#include "boost/python.hpp"
@@ -90,12 +90,19 @@ public:
// Returns a list of all the keys of available IPTC tags set in the
// image. This list has no duplicates: each of its items is unique,
// even if a tag is present more than once.
- //boost::python::list iptcKeys();
+ boost::python::list iptcKeys();
- // Return a list of tuples, each containing the type (as a string) and
- // the value (as a string as well) of the required IPTC tag.
+ // Return a tuple containing the type (as a string) and the value
+ // (as a string as well) of the required IPTC tag.
// Throw an exception if the tag is not set.
- //boost::python::list getIptcTag(std::string key);
+ // key
+ // tagname
+ // taglabel
+ // tagdesc
+ // type
+ // tagvalue (list)
+ // tagvalue (human-readable) (list)
+ boost::python::tuple getIptcTag(std::string key);
// Set the IPTC tag's value and return a tuple containing the
// type and previous value of the tag (empty strings if not previously
@@ -146,7 +153,7 @@ private:
std::string _filename;
Exiv2::Image::AutoPtr _image;
Exiv2::ExifData _exifData;
- //Exiv2::IptcData _iptcData;
+ Exiv2::IptcData _iptcData;
// true if the image's internal metadata has already been read,
// false otherwise